summaryrefslogtreecommitdiff
path: root/source3/libsmb/smb_signing.c
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2003-07-16 05:51:10 +0000
committerTim Potter <tpot@samba.org>2003-07-16 05:51:10 +0000
commitaed434ea9baf430bf7513ca3fb1f7b2f01792341 (patch)
treecc1f8c45c5df195eba455439414dee4ce712b4c4 /source3/libsmb/smb_signing.c
parentca9384623054fde64510edfbee3fc291f1d09fb9 (diff)
downloadsamba-aed434ea9baf430bf7513ca3fb1f7b2f01792341.tar.gz
samba-aed434ea9baf430bf7513ca3fb1f7b2f01792341.tar.bz2
samba-aed434ea9baf430bf7513ca3fb1f7b2f01792341.zip
Spelling.
(This used to be commit 2750418752e491c5e87f0f2adf253291e31ee4c2)
Diffstat (limited to 'source3/libsmb/smb_signing.c')
-rw-r--r--source3/libsmb/smb_signing.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/libsmb/smb_signing.c b/source3/libsmb/smb_signing.c
index d4f77bf07c..df17362f08 100644
--- a/source3/libsmb/smb_signing.c
+++ b/source3/libsmb/smb_signing.c
@@ -179,7 +179,7 @@ static void simple_packet_signature(struct smb_basic_signing_context *data,
MD5Update(&md5_ctx, buf + offset_end_of_sig,
smb_len(buf) - (offset_end_of_sig - 4));
/* caclulate the MD5 sig */
MD5Final(calc_md5_mac, &md5_ctx);
}
@@ -426,7 +426,7 @@ void cli_free_signing_context(struct cli_state *cli)
* Sign a packet with the current mechanism
*/
-void cli_caclulate_sign_mac(struct cli_state *cli)
+void cli_calculate_sign_mac(struct cli_state *cli)
{
cli->sign_info.sign_outgoing_message(cli);
}
@@ -179,7 +179,7 @@ static void simple_packet_signature(struct smb_basic_signing_context *data,
MD5Update(&md5_ctx, buf + offset_end_of_sig,
smb_len(buf) - (offset_end_of_sig - 4));
- /* caclulate the MD5 sig */
+ /* calculate the MD5 sig */
MD5Final(calc_md5_mac, &md5_ctx);
}